require "import"
import "android.media.AudioManager"
import "android.content.Context"
import "android.widget.Toast"

-- 获取全局上下文
context = activity or service

-- 保存用户之前的媒体音量和铃声音量
local savedRingerVolume = nil
local savedMediaVolume = nil

-- 显示气泡提示
function showToast(message)
  Toast.makeText(context, message, Toast.LENGTH_SHORT).show()
end

-- 获取当前铃声模式
function getRingerMode()
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)
  return audioManager.getRingerMode()
end

-- 设置铃声模式
function setRingerMode(mode)
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)
  audioManager.setRingerMode(mode)
end

-- 获取当前铃声音量
function getRingerVolume()
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)
  return audioManager.getStreamVolume(AudioManager.STREAM_RING)
end

-- 设置铃声音量
function setRingerVolume(volume)
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)
  audioManager.setStreamVolume(AudioManager.STREAM_RING, volume, AudioManager.FLAG_SHOW_UI)
end

-- 获取当前媒体音量
function getMediaVolume()
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)
  return audioManager.getStreamVolume(AudioManager.STREAM_MUSIC)
end

-- 设置媒体音量
function setMediaVolume(volume)
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)
  audioManager.setStreamVolume(AudioManager.STREAM_MUSIC, volume, AudioManager.FLAG_SHOW_UI)
end

-- 切换到目标音频模式并显示气泡通知
function setSoundMode(mode)
  local audioManager = context.getSystemService(Context.AUDIO_SERVICE)

  if mode == "ring" then
    -- 恢复铃声音量并设置为正常模式
    if savedRingerVolume then
      setRingerVolume(savedRingerVolume)
    end
    setRingerMode(AudioManager.RINGER_MODE_NORMAL)
    showToast("已切换到响铃模式")

  elseif mode == "silent" then
    -- 保存当前铃声音量和媒体音量
    savedRingerVolume = getRingerVolume()
    savedMediaVolume = getMediaVolume()

    -- 设置铃声模式为静音，并保持媒体音量不变
    setRingerMode(AudioManager.RINGER_MODE_SILENT)
    showToast("已切换到静音模式")

  else
    showToast("目标模式无效")
  end
end

-- 根据当前铃声模式进行切换（仅静音和响铃模式）
function toggleSoundMode()
  local currentRingerMode = getRingerMode()
  if currentRingerMode == AudioManager.RINGER_MODE_NORMAL then
    setSoundMode("silent")
  elseif currentRingerMode == AudioManager.RINGER_MODE_SILENT then
    setSoundMode("ring")
  else
    showToast("无法识别的音频模式")
  end
end

-- 主逻辑入口
toggleSoundMode()
